summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/Kolinestyleaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/Kolinestyleaction.h')
-rw-r--r--lib/kofficeui/Kolinestyleaction.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/lib/kofficeui/Kolinestyleaction.h b/lib/kofficeui/Kolinestyleaction.h
index ff8086f8..6d8d9e91 100644
--- a/lib/kofficeui/Kolinestyleaction.h
+++ b/lib/kofficeui/Kolinestyleaction.h
@@ -26,24 +26,25 @@
class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructs a KoLineStyleAction with a text and an icon.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoLineStyleAction(const QString& text, const QString& icon, QObject* parent = 0, const char* name = 0);
+ KoLineStyleAction(const TQString& text, const TQString& icon, TQObject* tqparent = 0, const char* name = 0);
/** Same as above, but it also connects a slot to the selectionChanged(int) signal.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke when a selectionChanged(int) signal is emited.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoLineStyleAction(const QString& text, const QString& icon, const QObject* receiver,
- const char* slot, QObject* parent, const char* name = 0);
+ KoLineStyleAction(const TQString& text, const TQString& icon, const TQObject* receiver,
+ const char* slot, TQObject* tqparent, const char* name = 0);
~KoLineStyleAction();
protected:
@@ -26,24 +26,25 @@
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -26,24 +26,25 @@
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke when a selectionChanged(int) signal is emited.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke when a selectionChanged(int) signal is emited.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/